Interface: ScriptableScaleContext | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ScriptableScaleContext

## # Properties

### # chart

• chart: `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`>

#### # Defined in

index.esm.d.ts:1341
(opens new window)

### # index

• index: `number`

#### # Defined in

index.esm.d.ts:1343
(opens new window)

### # scale

• scale: `Scale`<`CoreScaleOptions`>

#### # Defined in

index.esm.d.ts:1342
(opens new window)

### # tick

• tick: `Tick`

#### # Defined in

index.esm.d.ts:1344
(opens new window)